# -*- coding: utf-8 -*-
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Jaime Soriano
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


from gtkmvc import Controller

from wader.gtk.dialogs import show_profile_window

from wader.gtk.logger import logger

class PreferencesController(Controller):

    def __init__(self, model):
        super(PreferencesController, self).__init__(model)

    def register_view(self, view):
        super(PreferencesController, self).register_view(view)

    def hide_ourselves(self):
        self.model.unregister_observer(self)
        self.view.get_top_widget().destroy()
        self.view = None
        self.model = None

    def _connect_to_signals(self):
        pass

    def on_cancel_button_clicked(self, event):
        self.hide_ourselves()

    def on_ok_button_clicked(self, event):
        self.model.save()
        self.hide_ourselves()

    def on_warn_limit_check_toggled(self, toggle):
        self.model.warn_limit = toggle.get_active()

    def on_transfer_limit_entry_value_changed(self, entry):
        self.model.transfer_limit = entry.get_value()

    def on_reset_statistics_button_clicked(self, button):
        self.model.reset_statistics()

    def on_add_profile_button_clicked(self, event):
        main_model = self.model.main_model
        if main_model.device:
            main_model.get_imsi(lambda imsi:
                show_profile_window(self.model, imsi=imsi))
        else:
            show_profile_window(self.model)

    def on_modify_profile_button_clicked(self, event):
        try:
            profile = self.view.profiles_treeview.get_selected_profile()
            show_profile_window(main_model=self.model, profile=profile)
        except Exception, e:
            logger.error("Modify profile button clicked: %s" % e.message)

    def on_delete_profile_button_clicked(self, event):
        try:
            profile = self.view.profiles_treeview.get_selected_profile()
            if profile:
                profile.delete()
        except Exception, e:
            logger.error("Delete profile button clicked: %s" % e.message)

    def property_warn_limit_value_change(self, model, old, new):
        if new != self.view['warn_limit_check'].get_active():
            self.view['warn_limit_check'].set_active(new)

    def property_transfer_limit_value_change(self, model, old, new):
        if new != self.view['transfer_limit_entry'].get_value():
            self.view['transfer_limit_entry'].set_value(new)

    def property_profiles_value_change(self, model, old, new):
        if old is None: return

        # Items in old and not in new are removed items
        for profile_path, profile in old.iteritems():
            if not profile_path in new.keys():
                self.profile_removed(profile)

        # Items in new and not in old are added items
        for profile_path, profile in new.iteritems():
            if not profile_path in old.keys():
                self.profile_added(profile)

    def property_profiles_default_profile_change(self, model, old, new):
        try:
            self.view.set_default_profile(new)
        except:
            pass

    def profile_removed(self, profile):
        profile = self.view.remove_profile(profile)

    def profile_added(self, profile):
        profile = self.view.add_profile(profile)
