# -*- coding: utf-8 -*-
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Jaime Soriano
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


from gtkmvc import Controller

class ProfileController(Controller):

    def __init__(self, model):
        super(ProfileController, self).__init__(model)

    def register_view(self, view):
        super(ProfileController, self).register_view(view)

    def setup_view(self, view):
        self.view['profile_name_entry'].set_text(self.model.name)
        self.view['username_entry'].set_text(self.model.username)
        self.view['password_entry'].set_text(self.model.password)
        self.view.set_connection_mode(self.model.connection)
        self.view['apn_entry'].set_text(self.model.apn)
        self.view['static_dns_check'].set_active(self.model.static_dns)
        self.view['primary_dns_entry'].set_text(self.model.primary_dns)
        self.view['secondary_dns_entry'].set_text(self.model.secondary_dns)
        if self.model.static_dns:
            self.view.enable_static_dns()
        self._connect_to_signals()

    def hide_ourselves(self):
        self.model.unregister_observer(self)
        self.view.get_top_widget().destroy()
        self.view = None
        self.model = None

    def _connect_to_signals(self):
        pass

    def on_cancel_button_clicked(self, widget):
        self.hide_ourselves()

    def on_ok_button_clicked(self, widget):
        self.model.name = self.view['profile_name_entry'].get_text()
        self.model.username = self.view['username_entry'].get_text()
        self.model.password = self.view['password_entry'].get_text()
        self.model.connection = \
                        self.view['connection_combobox'].get_active_text()
        self.model.apn = self.view['apn_entry'].get_text()
        self.model.static_dns = self.view['static_dns_check'].get_active()
        if self.view['static_dns_check'].get_active():
            self.model.primary_dns = self.view['primary_dns_entry'].get_text()
            self.model.secondary_dns = \
                self.view['secondary_dns_entry'].get_text()

        self.model.save()
        self.hide_ourselves()

    def property_name_value_change(self, model, old, new):
        self.view['profile_name_entry'].set_text(new)

    def property_username_value_change(self, model, old, new):
        self.view['username_entry'].set_text(new)

    def property_password_value_change(self, model, old, new):
        self.view['password_entry'].set_text(new)

    def property_connection_value_change(self, model, old, new):
        self.view.set_connection_mode(new)

    def property_apn_value_change(self, model, old, new):
        self.view['apn_entry'].set_text(new)

    def property_primary_dns_value_change(self, model, old, new):
        if (not old or len(old) == 0) and len(new) > 0:
            self.view.enable_static_dns()
        self.view['primary_dns_entry'].set_text(new)

    def property_secondary_dns_value_change(self, model, old, new):
        if (not old or len(old) == 0) and len(new) > 0:
            self.view.enable_static_dns()
        self.view['secondary_dns_entry'].set_text(new)
