# -*- coding: utf-8 -*-
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Jaime Soriano
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


class ValidationError(Exception):
    pass

def validate_non_empty_string(string):
    return string and len(string) > 0

def validate_number(number):
    try:
        int(number)
        return True
    except:
        return False

def validate_ip(ip):
    try:
        for number in ip.split('.'):
            number = int(number)
            if number < 0 or number > 255:
                return False
    except Exception, e:
        return False
    return True


class ModelValidation(object):
    def __init__(self, value, function, message):
        self.value = value
        self.function = function
        self.message = message

    def check(self, model):
        if not self.function(model.__getattribute__(self.value)):
            raise ValidationError(self.message)

class ModelValidator(object):
    def __init__(self, model):
        self.validations = []
        self.model = model

    def add_validation(self, value, function, message):
        self.validations.append(ModelValidation(value, function, message))

    def remove_validation(self, validation):
        self.validations.remove(validation)

    def check(self):
        for validation in self.validations:
            validation.check(self.model)
