# -*- coding: utf-8 -*-
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Jaime Soriano
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


import gtk
import os
import gobject

from wader.gtk.consts import GLADE_DIR

from gtkmvc import View

PROFILES_FRAME, STATISTICS_FRAME = xrange(2)
PREFERENCES_FRAMES = (PROFILES_FRAME, STATISTICS_FRAME)
PREFERENCES_LABEL = {
    PROFILES_FRAME : "Profiles",
    STATISTICS_FRAME : "Statistics",
}

class PreferencesList(gtk.TreeView):
    def __init__(self, activate_callback):
        store = gtk.ListStore(gobject.TYPE_STRING)
        super(PreferencesList, self).__init__(store)
        self.set_headers_visible(False)

        self.activate_callback = activate_callback

        self._init_model()
        self._init_view_columns()

    def _init_model(self):
        store = self.get_model()
        for frame in PREFERENCES_FRAMES:
            store.append((PREFERENCES_LABEL[frame],))

    def _init_view_columns(self):
        col = gtk.TreeViewColumn()

        render_text = gtk.CellRendererText()
        col.pack_start(render_text, expand=True)
        col.add_attribute(render_text, 'text', 0)

        self.append_column(col)

        self.connect('cursor-changed', self._cursor_changed)
        self.get_selection().set_mode(gtk.SELECTION_SINGLE)       

    def _row_activated_handler(self, treeview, path, col):
        print treeview, path, col

    def _cursor_changed(self, treeview):
        model, selected = self.get_selection().get_selected_rows()
        if len(selected) == 1:
            self.activate_callback(selected[0][0])

class ProfilesList(gtk.TreeView):
    def __init__(self):
        store = gtk.ListStore(gobject.TYPE_BOOLEAN, gobject.TYPE_STRING)
        super(ProfilesList, self).__init__(store)
        self.set_headers_visible(False)

        self.profiles = {}

        self.default_profile_iter = None

        self._init_view_columns()

    def _init_view_columns(self):
        col = gtk.TreeViewColumn()
        render_toggle = gtk.CellRendererToggle()
        render_toggle.set_radio(True)
        render_toggle.set_data('column', 0)
        col.pack_start(render_toggle, expand=False)
        col.add_attribute(render_toggle, 'active', 0)
        render_toggle.connect("toggled", self.on_item_toggled)
        self.append_column(col)

        col = gtk.TreeViewColumn()
        render_text = gtk.CellRendererText()
        col.pack_start(render_text, expand=True)
        col.add_attribute(render_text, 'text', 1)
        self.append_column(col)

        self.get_selection().set_mode(gtk.SELECTION_SINGLE)

    def on_item_toggled(self, cell, path):
        model = self.get_model()
        iter = model.get_iter(path)
        profile_name = model.get_value(iter, 1)
        self.set_default_profile(profile_name)

    def set_default_profile(self, profile_name):
        model = self.get_model()
        iter = self.profiles[profile_name][1]
        profile = self.profiles[profile_name][0]
        if self.default_profile_iter:
            if iter != self.default_profile_iter:
                profile.set_as_default()
            model.set(self.default_profile_iter, 0, False)
        else:
            profile.set_as_default()
        self.default_profile_iter = iter
        model.set(iter, 0, True)        

    def add_profile(self, profile):
        store = self.get_model()
        if not self.profiles.has_key(profile.name):
            self.profiles[profile.name] = (
                profile, 
                store.append((False, profile.name,)))

    def remove_profile(self, profile):
        store = self.get_model()
        store.remove(self.profiles[profile.name][1])
        del(self.profiles[profile.name])

    def get_selected_profile(self):
        model, selected = self.get_selection().get_selected_rows()
        if not selected or len(selected) > 1:
            return self.device_iters.keys()[1]
        _iter = model.get_iter(selected[0])
        profile_name = model.get_value(_iter, 1)
        return self.profiles[profile_name][0]

class PreferencesView(View):

    GLADE_FILE = os.path.join(GLADE_DIR, "preferences.glade")

    def __init__(self, ctrl):
        super(PreferencesView, self).__init__(ctrl, self.GLADE_FILE, 
                                              'preferences_window')
        self['preferences_notebook'].set_show_tabs(False)
        self._init_preferences_treeview()
        self._init_profiles_treeview()
        ctrl._connect_to_signals()

        for profile in ctrl.model.get_profiles().values():
            self.add_profile(profile)
        ctrl.model.load()
        self.set_default_profile(ctrl.model.default_profile)
        self.change_panel(PROFILES_FRAME)

    def _init_preferences_treeview(self):
        self.preferences_treeview = PreferencesList(self.change_panel)
        self['preferences_view'].add(self.preferences_treeview)

    def _init_profiles_treeview(self):
        self.profiles_treeview = ProfilesList()
        self['profiles_view'].add(self.profiles_treeview)

    def change_panel(self, panel):
        self['preferences_notebook'].set_current_page(panel)

    def add_profile(self, profile):
        self.profiles_treeview.add_profile(profile)

    def remove_profile(self, profile):
        self.profiles_treeview.remove_profile(profile)

    def set_default_profile(self, profile):
        if profile:
            self.profiles_treeview.set_default_profile(profile.name)
