# -*- coding: utf-8 -*-
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Jaime Soriano
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


import gtk
import os
import gobject

from wader.gtk.consts import GLADE_DIR
from wader.common.hardware import CONN_OPTS_REV

from gtkmvc import View

class ProfileView(View):

    GLADE_FILE = os.path.join(GLADE_DIR, "profiles.glade")

    def __init__(self, ctrl):
        super(ProfileView, self).__init__(ctrl, self.GLADE_FILE, 
                                          'new_profile_window')
        self._init_connection_options()
        ctrl.setup_view(self)
        self['static_dns_check'].connect('toggled', self.on_static_dns_toggled)

    def _init_connection_options(self):
        model = gtk.ListStore(gobject.TYPE_STRING)
        options = CONN_OPTS_REV.keys()
        options.sort()
        for opt in options:
            iter = model.append([opt])
        self['connection_combobox'].set_model(model)
        self.set_connection_mode('3GPREF')
   
    def set_connection_mode(self, mode):
        model = self['connection_combobox'].get_model()
        for i, row in enumerate(model):
            if row[0].lower() == mode.lower():
                self['connection_combobox'].set_active(i)
                break

    def on_static_dns_toggled(self, widget):
        if widget.get_active():
            self.enable_static_dns()
        else:
            self.disable_static_dns()

    def disable_static_dns(self):
        self['primary_dns_entry'].set_sensitive(False)
        self['secondary_dns_entry'].set_sensitive(False)
        if self['static_dns_check'].get_active():
            self['static_dns_check'].set_active(False)

    def enable_static_dns(self):
        self['primary_dns_entry'].set_sensitive(True)
        self['secondary_dns_entry'].set_sensitive(True)
        if not self['static_dns_check'].get_active():
            self['static_dns_check'].set_active(True)
